@@ -1,4 +1,5 @@
 from pathlib import Path
+from tempfile import NamedTemporaryFile
 from typing import Literal, Optional, Sequence, cast
 
 from invoke import Collection, Context, Result, UnexpectedExit, task
@@ -56,10 +57,13 @@ def clean(c: Context):  # noqa: A001, WPS125
 def types(c: Context, show_information: bool = False):
     """Run type-checking."""
     directories = env.r(check_targets)
-    res = cast(Result, c.run(f'poetry run pyright {directories} --outputjson', echo=True, hide=True, warn=True))
 
-    assert isinstance(res.stdout, str)
-    results = PyrightOutput.parse_raw(res.stdout)
+    tmp_handler = NamedTemporaryFile()
+    res = cast(
+        Result, c.run(f'poetry run pyright {directories} --outputjson > {tmp_handler.name}', echo=True, hide=True, warn=True),
+    )
+
+    results = PyrightOutput.parse_raw(tmp_handler.read())
 
     console = Console()
 
