@@ -23,12 +23,12 @@ def run_tests(  # noqa: WPS211
     c.run(f'poetry run coverage run --context={coverage} -m pytest {options_string} {target}', env=env, in_stream=not capture)
 
     if is_ci():
-        c.run('poetry run coverage report -m')
+        c.run('poetry run coverage report -m', env=env)
     else:
         # Run a first coverage, to the console but don't fail based on %
-        c.run('poetry run coverage report -m --fail-under 0')
+        c.run('poetry run coverage report -m --fail-under 0', env=env)
         # Run a second coverage to output html, and fail according to %
-        c.run('poetry run coverage html --show-contexts')
+        c.run('poetry run coverage html --show-contexts', env=env)
 
 
 @task(clean_tasks.docs, clean_tasks.python, clean_tasks.coverage, clean_tasks.pacts)
